@@ -256,7 +256,8 @@ class Crystal(DataN):
                                                     f_hkl_as)
         return f_nucl
 
-    def calc_refln(self, index_h, index_k, index_l, flag_internal=True):
+    def calc_refln(self, index_h, index_k, index_l,
+                   flag_internal: bool = True):
         """
         Calculate Refln cryspy object where nuclear structure factor is stored.
 
@@ -289,8 +290,8 @@ class Crystal(DataN):
             res.numpy_to_items()
         return res
 
-    def calc_susceptibility_moment_tensor(self, index_h, index_k, index_l,
-                                          flag_only_orbital=False):
+    def calc_susceptibility_moment_tensor(
+            self, index_h, index_k, index_l, flag_only_orbital: bool = False):
         """
         Susceptibility tensor function.
 
@@ -520,8 +521,9 @@ class Crystal(DataN):
         return s_11, s_12, s_13, s_21, s_22, s_23, s_31, s_32, s_33, \
             sm_11, sm_12, sm_13, sm_21, sm_22, sm_23, sm_31, sm_32, sm_33
 
-    def calc_refln_susceptibility(self, index_h, index_k, index_l,
-                                  flag_internal=True, flag_only_orbital=False):
+    def calc_refln_susceptibility(
+            self, index_h, index_k, index_l, flag_internal: bool = True,
+            flag_only_orbital: bool = False):
         """
         Calculate susceptibility tensor and moment tensor.
 
@@ -589,7 +591,7 @@ class Crystal(DataN):
             cell.ortogonalize_matrix(l_ij)
         return s_11, s_12, s_13, s_21, s_22, s_23, s_31, s_32, s_33
 
-    def calc_hkl(self, sthol_min: float, sthovl_max: float):
+    def calc_hkl(self, sthol_min: float = 0., sthovl_max: float = 1.):
         """
         Give hkl taking symmetry into account.
 
@@ -611,7 +613,7 @@ class Crystal(DataN):
         res = cell.calc_hkl(space_group, sthol_min, sthovl_max)
         return res
 
-    def calc_hkl_in_range(self, sthol_min: float, sthovl_max: float):
+    def calc_hkl_in_range(self, sthol_min: float = 0., sthovl_max: float = 1.):
         """
         Give hkl without taking symmetry into account.
 
@@ -640,11 +642,14 @@ class Crystal(DataN):
 
         Negtive eigenvalues of ellipsoid are replaced by positive.
         """
-        cell = self.cell
-        a_s_m_a = self.atom_site_susceptibility
+        l_res = []
+        try:
+            cell = self.cell
+            a_s_m_a = self.atom_site_susceptibility
+        except AttributeError:
+            return l_res
         m_m_norm = cell.m_m_norm
         m_im_norm = numpy.linalg.inv(m_m_norm)
-        l_res = []
         for _l, _11, _22, _33, _12, _13, _23 in zip(
                 a_s_m_a.label, a_s_m_a.chi_11, a_s_m_a.chi_22, a_s_m_a.chi_33,
                 a_s_m_a.chi_12, a_s_m_a.chi_13, a_s_m_a.chi_23):
@@ -663,76 +668,31 @@ class Crystal(DataN):
         return l_res
 
     def calc_main_axes_of_magnetization_ellipsoids(self):
-        """
-        Susceptibility along the main axes of magnetization ellipsoid.
-
-        In Bohr magneton for each magnetic atom.
-
-        The main axes are given in Cartezian coordinate system (x||a*, z||c).
+        """Susceptibility along the main axes of magnetization ellipsoid.
 
         Output
         ------
-            arg1: the list of the suscetibility along main axes for each atom
-            arg2: the list of directions for each atom
+            - l_moments is main axes of ellipsoid in mu_B/T for each atom
+            - l_moments_sigma is sigmas for main axes of ellipsoid for each
+              atom
+            - l_rot_matrix is directions for moments
+                for moments[0] direction is rot_matrix[:, 0]
+                for moments[1] direction is rot_matrix[:, 1]
+                for moments[2] direction is rot_matrix[:, 2]
 
-        Example
-        -------
-            >>> # crystal is defined object of cryspy library;
-            >>> # type(crystal) is Crystal
-            >>> l_susceptibilities, l_directions = \
-                crystal.calc_main_axes_of_magnetization_ellipsoids()
-            >>> #cycle over magnetic atoms
-            >>> for susceptibilities, directions in zip(l_susceptibilities,
-                                                        l_directions):
-            >>>     #cycle over three main axes
-            >>>     for _val1, _direction in zip(susceptibilities, directions):
-            >>>         print(f"{_val1: 9.5f} mu_B/T \
-                              along: {_direction[0]: 9.5f} \
-                                  {_direction[1]: 9.5f} {_direction[2]: 9.5f}")
-            >>>     print("")
-            >>> print("Cartezian coordinate system is x||a*, z||c.")
+        The main axes are given in Cartezian coordinate system (x||a*, z||c).
         """
-        cell = self.cell
-        a_s_s = self.atom_site_susceptibility
-        if a_s_s is None:
-            return None
-        m_m_norm = cell.m_m_norm
         ll_moments = []
         ll_directions = []
-        for it_a_s_s in a_s_s.items:
-            _11, _22, _33 = it_a_s_s.chi_11, it_a_s_s.chi_22, it_a_s_s.chi_33
-            _12, _13, _23 = it_a_s_s.chi_12, it_a_s_s.chi_13, it_a_s_s.chi_23
+        try:
+            cell = self.cell
+            a_s_s = self.atom_site_susceptibility
+        except AttributeError:
+            return ll_moments, ll_directions
 
-            sig_11, sig_22 = it_a_s_s.chi_11_sigma, it_a_s_s.chi_22_sigma
-            sig_33, sig_12 = it_a_s_s.chi_33_sigma, it_a_s_s.chi_12_sigma
-            sig_13, sig_23 = it_a_s_s.chi_13_sigma, it_a_s_s.chi_23_sigma
-
-            m_chi_loc = numpy.array([[_11, _12, _13], [_12, _22, _23],
-                                     [_13, _23, _33]], dtype=float)
-            m_chi_orto = numpy.matmul(numpy.matmul(m_m_norm, m_chi_loc),
-                                      m_m_norm.transpose())
-
-            val, vec = numpy.linalg.eigh(m_chi_orto)
-            flag_error = (
-                math.isclose(sig_11, 0.) & math.isclose(sig_22, 0.) &
-                math.isclose(sig_33, 0.) & math.isclose(sig_12, 0.) &
-                math.isclose(sig_13, 0.) & math.isclose(sig_23, 0.))
-
-            if not(flag_error):
-                np_sigma = numpy.array([[sig_11, sig_12, sig_13],
-                                        [sig_12, sig_22, sig_23],
-                                        [sig_13, sig_23, sig_33]],
-                                       dtype=float)
-                M1 = numpy.matmul(vec.transpose(), m_m_norm)
-                M2 = calc_m_sigma(M1, np_sigma)
-                l_sig = [sum(M2[:, 0]**2)**0.5, sum(M2[:, 1]**2)**0.5,
-                         sum(M2[:, 2]**2)**0.5]
-                val = [(_1, _2) for _1, _2 in zip(val, l_sig)]
-            l_moments = list(val)
-            l_directions = [vec[:, 0], vec[:, 1], vec[:, 2]]
-            ll_moments.append(l_moments)
-            ll_directions.append(l_directions)
-        return ll_moments, ll_directions
+        l_moments, l_moments_sigma, l_rot_matrix = \
+            a_s_s.calc_main_axes_of_magnetization_ellipsoid(cell)
+        return l_moments, l_moments_sigma, l_rot_matrix
 
     def report_main_axes_of_magnetization_ellipsoids(self):
         """
@@ -746,25 +706,27 @@ class Crystal(DataN):
         ls_out = []
         # crystal is defined object of cryspy library;
         # type(crystal) is Crystal
-        try:
+        if self.is_attribute("atom_site_susceptibility"):
             a_s_m_a = self.atom_site_susceptibility
-        except AttributeError:
-            return None
-        l_susceptibilities, l_directions = \
+        else:
+            return ""
+        l_moments, l_moments_sigma, l_rot_matrix = \
             self.calc_main_axes_of_magnetization_ellipsoids()
         l_chi_as_u = self.calc_magnetization_ellipsoid()
         # cycle over magnetic atoms
-        for label, susceptibilities, directions, chi_as_u in \
-                zip(a_s_m_a.label, l_susceptibilities, l_directions,
-                    l_chi_as_u):
+        for label, susceptibilities, susceptibilities_sigma, rot_matrix, \
+            chi_as_u in zip(a_s_m_a.label, l_moments, l_moments_sigma,
+                            l_rot_matrix, l_chi_as_u):
             ls_out.append(f"For `{label:}` the susceptibility is:")
             # cycle over three main axes
-            for _val1, _direction in zip(susceptibilities, directions):
-                if isinstance(_val1, tuple):
-                    s_param = value_error_to_string(*_val1)
-                    s_val = f"{s_param:}".rjust(9)
-                else:
+            directions = rot_matrix.transpose()
+            for _val1, val_sigma, _direction in zip(
+                    susceptibilities, susceptibilities_sigma, directions):
+                if math.isclose(val_sigma, 0.):
                     s_val = f"{_val1: 9.5f}".rjust(9)
+                else:
+                    s_param = value_error_to_string(_val1, val_sigma)
+                    s_val = f"{s_param:}".rjust(9)
                 ls_out.append(
                     f"{s_val:} mu_B/T along: {_direction[0]: 9.5f} \
 {_direction[1]: 9.5f} {_direction[2]: 9.5f}")
@@ -790,15 +752,20 @@ class Crystal(DataN):
         (a/|a|, b/|b|, c/|c|)
         """
         np_field = numpy.array(field_abc, dtype=float)
-        spgr = self.space_group
+        l_lab_out, l_xyz_out, l_moment_out = [], [], []
+
+        try:
+            spgr = self.space_group
+            cell = self.cell
+            a_s = self.atom_site
+            a_s_m_a = self.atom_site_susceptibility
+        except AttributeError:
+            return l_lab_out, l_xyz_out, l_moment_out
 
-        cell = self.cell
         m_m_norm = cell.m_m_norm
         m_mt_norm_m_norm_field = numpy.matmul(
             numpy.matmul(m_m_norm.transpose(), m_m_norm), np_field)
-        a_s = self.atom_site
-        a_s_m_a = self.atom_site_susceptibility
-        l_lab_out, l_xyz_out, l_moment_out = [], [], []
+
         for _l, _11, _22, _33, _12, _13, _23 in zip(
                 a_s_m_a.label, a_s_m_a.chi_11, a_s_m_a.chi_22, a_s_m_a.chi_33,
                 a_s_m_a.chi_12, a_s_m_a.chi_13, a_s_m_a.chi_23):
