@@ -67,7 +67,7 @@ __author__ = 'Iurii KIBALIN'
 __copyright__   = "Copyright 2020, "
 __credits__ = ["Iurii KIBALIN", "Andrew SAZONOV", "Arsen GOUKASSOV"]
 __license__ = "GPL"
-__version__ = "0.4.14"
+__version__ = "0.4.17"
 __maintainer__ = "Iurii KIBALIN"
 __email__ = "iurii.kibalin@cea.fr"
 __status__ = "Development"
@@ -113,6 +113,7 @@ from cryspy.C_item_loop_classes.cl_1_atom_type import AtomType, \
     AtomTypeL
 from cryspy.C_item_loop_classes.cl_1_atom_site_aniso import \
     AtomSiteAniso, AtomSiteAnisoL
+from cryspy.C_item_loop_classes.cl_1_hessian_matrix import HessianMatrix
 from cryspy.C_item_loop_classes.cl_1_refln import Refln, ReflnL
 from cryspy.C_item_loop_classes.cl_1_atom_site_susceptibility import \
     AtomSiteSusceptibility, AtomSiteSusceptibilityL
@@ -171,6 +172,9 @@ from cryspy.C_item_loop_classes.cl_2_diffrn_orient_matrix import \
 
 from cryspy.C_item_loop_classes.cl_3_density_point import DensityPointL
 
+from cryspy.D_functions_item_loop.function_1_section_from_density_point \
+    import calc_section_from_density_point
+
 from cryspy.E_data_classes.cl_1_crystal import Crystal
 from cryspy.E_data_classes.cl_2_diffrn import Diffrn
 from cryspy.E_data_classes.cl_2_pd import Pd
